% Copyright (c) 2011 Joris Degroote, Majid Hojjat, Electra Stavropoulou,
% Roland Wüchner, Kai-Uwe Bletzinger
%
% Licensed under the Non-Profit Open Software License version 3.0
% (NPOSL-3.0). You should have received a copy of the NPOSL-3.0 along with 
% this file. If not, see <http://www.opensource.org/licenses/NPOSL-3.0>
%
% Creation of plots.

function MakePlots()
    linewidth=2.0;
    fontsize=16;
    
    names={'Smooth','Step'};
    styles={'ko-','kx-'};
    handle=figure;
    hold('on');
    for i=1:length(names)
        data=load(['Convergence' names{i} '.txt']);
        plot(data(:,1),data(:,3),styles{i},'LineWidth',linewidth);    
    end
    hold('off');
    set(gca,'YScale','log','FontSize',fontsize);
    xlabel('Iteration [-]','FontSize',fontsize);
    ylabel('Cost function [-]','FontSize',fontsize);
    xlim([0 data(end,1)+1]);
    legend('Smooth','Stepwise');
    print(handle,'-deps','-r2400 -zbuffer','Convergence');
    close(handle);
    
    names={'Minimal','Nominal','Maximal'};
    styles={'k-.','k-','k--'};
    handle=figure;
    hold('on');
    for i=1:length(names)
        data=load(['History' names{i} '.txt']);
        plot(data(:,1),data(:,2),styles{i},'LineWidth',linewidth);    
    end
    hold('off');
    set(gca,'FontSize',fontsize);
    xlabel('Time [s]','FontSize',fontsize);
    ylabel('Radius [m]','FontSize',fontsize);
    xlim([0 data(end,1)]);
    legend(names);
    print(handle,'-deps','-r2400 -zbuffer','History');
    close(handle);
    
    handle=figure;
    data=load('Gradient.txt');
    plot(data(1:end-1),'k-','LineWidth',linewidth);    
    set(gca,'FontSize',fontsize);
    xlabel('m [-]','FontSize',fontsize);
    ylabel('dj/ds [-]','FontSize',fontsize);
    print(handle,'-deps','-r2400 -zbuffer','Gradient');
    close(handle);
    
    names={'Forward','Adjoint'};
    styles={'k-','k-.','k--','k:'};
    locations={'West','NorthEast'};
    for i=1:length(names)
        data=load(['V' names{i} '.txt']);
        handle=figure;
        hold('on');
        for j=1:size(data,2)
            plot(data(:,j)/max(abs(data(:,j))),styles{j},'LineWidth', ...
                linewidth);
        end
        hold('off');
        set(gca,'FontSize',fontsize);
        xlabel('row [-]','FontSize',fontsize);
        ylabel('V_{row,col} [-]','FontSize',fontsize);
        legend('col=1','col=2','col=3','col=4','Location', ...
            locations{i});
        print(handle,'-deps','-r2400 -zbuffer',['V' names{i}]);
        close(handle);
    end
    
    names={'QuasiNewton','QuasiNewtonReuse','GaussSeidel'};
    styles={'ko-','kx-','kv-'};
    handle=figure;
    hold('on');
    for i=1:length(names)
        data=load(['Convergence' names{i} '.txt']);
        range=1:min(size(data,1),20);
        plot(data(range,3),styles{i},'LineWidth',linewidth);    
    end
    hold('off');
    set(gca,'YScale','log','FontSize',fontsize);
    xlabel('Coupling iteration [-]','FontSize',fontsize);
    ylabel('Coupling residual [m]','FontSize',fontsize);
    legend('QN','QN(3)','GS','Location','NorthWest');
    print(handle,'-deps','-r2400 -zbuffer','ConvergenceCouplingForward');
    close(handle);
    
    handle=figure;
    hold('on');
    start={528,304};
    for i=1:length(names)-1
        data=load(['Convergence' names{i} '.txt']);
        range=start{i}:start{i}+19;
        plot(data(range,3),styles{i},'LineWidth',linewidth);    
    end
    hold('off');
    set(gca,'YScale','log','FontSize',fontsize);
    xlabel('Coupling iteration [-]','FontSize',fontsize);
    ylabel('Coupling residual [m]','FontSize',fontsize);
    legend('QN','QN(3)','Location','NorthEast');
    print(handle,'-deps','-r2400 -zbuffer','ConvergenceCouplingAdjoint');
    close(handle);
end