% Copyright (c) 2011 Joris Degroote, Majid Hojjat, Electra Stavropoulou,
% Roland Wüchner, Kai-Uwe Bletzinger
%
% Licensed under the Non-Profit Open Software License version 3.0
% (NPOSL-3.0). You should have received a copy of the NPOSL-3.0 along with 
% this file. If not, see <http://www.opensource.org/licenses/NPOSL-3.0>
%
% Test of the optimiser.

function TestOptimiser()
    for p=0:8
        m=10^p;
        x0=zeros(m,1);
        options=optimset('MaxIter',100,'MaxFunEvals',100,'TolX',1e-6, ... 
            'TolFun',1e-6,'MaxNodes',10);
        [x,f,exitflag,output,grad]=Optimiser(@Dummy,x0,options);
        if ((max(abs(x-2.0))>1.0e-4)||(abs(f-2.0)>1.0e-4)|| ...
            (exitflag<1)||(output.iterations~=1)|| ...
            (norm(grad,Inf)>1.0e-4))
            error('Test failed');
        end
    end
    
    x0=zeros(2,1);
    options=optimset('MaxIter',100,'MaxFunEvals',100,'TolX',1e-6, ... 
        'TolFun',1e-6,'MaxNodes',10);
    [x,f,exitflag,output,grad]=Optimiser(@Rosenbrock,x0,options);
    if ((max(abs(x-1.0))>1.0e-4)||(abs(f)>1.0e-4)|| ...
        (exitflag<1)||(output.iterations>=100)|| ...
        (norm(grad,Inf)>1.0e-4))
        error('Test failed');
    end
    
    function [j,djdx]=Dummy(x)
        j=2.0+(x-2.0)'*(x-2.0);
        djdx=2.0*(x-2.0)';
    end

    function [j,djdx]=Rosenbrock(x)
        j=(1.0-x(1))^2+100.0*(x(2)-x(1)^2)^2;
        djdx=[-2.0*(1.0-x(1))-400.0*(x(2)-x(1)^2)*x(1) ...
            200.0*(x(2)-x(1)^2)];
    end
end